<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://welaunch.io/plugins
 * @since      1.0.0
 *
 * @package    WordPress_Form_Wizard
 * @subpackage WordPress_Form_Wizard/admin
 */
class WordPress_Form_Wizard_Admin extends WordPress_Form_Wizard {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	protected $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of this plugin.
	 */
	protected $version;

	protected $branded;

	/**
	 * Construct the Class
	 * @author Daniel Barenkamp
	 * @version 1.0.0
	 * @since   1.0.0
	 * @link    https://welaunch.io
	 * @param   [type]                       $plugin_name [description]
	 * @param   [type]                       $version     [description]
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->branded = false;
		$this->userRoles = array();
		
	}

    /**
     * Enqueue Admin Styles
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    http://www.welaunch.io
     * @return  boolean
     */
    public function enqueue_scripts_styles()
    {
    	wp_enqueue_style( 'boxicons', plugin_dir_url( dirname( __FILE__ ) ) . 'assets/vendor/boxicons/css/boxicons.min.css', array(), '2.1.4', 'all' );
        wp_enqueue_style( $this->plugin_name.'-admin', plugin_dir_url( dirname( __FILE__ ) ) . 'assets/css/wordpress-form-wizard-admin.css', array(), $this->version, 'all');
        
        wp_enqueue_script( $this->plugin_name.'-admin', plugin_dir_url( dirname( __FILE__ ) ) . 'assets/js/wordpress-form-wizard-admin.js', array('jquery'), $this->version, true);
        if ( ! did_action( 'wp_enqueue_media' ) ) {
            wp_enqueue_media();
        }

		$forJS = array(
			'placeholder_image_src' => plugin_dir_url( dirname( __FILE__ ) ) . 'assets/img/placeholder.png',
			'admin_url' => admin_url(),
			'ajax_url' => admin_url('admin-ajax.php'),
			'promptsAnswer' => esc_html__("Please enter your Answer", 'wordpress-form-wizard'),
			'promptsQuestion' => esc_html__("Please enter your Question", 'wordpress-form-wizard'),
		);
        
        wp_localize_script($this->plugin_name . '-admin', 'form_wizard_options', $forJS);
    }

    /**
     * Enqueue Admin Scripts
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    http://www.welaunch.io
     * @return  boolean
     */
    public function enqueue_scripts()
    {

    }

	/**
	 * Load Redux
	 * @author Daniel Barenkamp
	 * @version 1.0.0
	 * @since   1.0.0
	 * @link    https://welaunch.io
	 * @return  [type]                       [description]
	 */
	public function load_redux(){
	    if ( file_exists( plugin_dir_path( dirname( __FILE__ ) ) . 'config/options-init.php' ) ) {
	        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'config/options-init.php';
	    }
	}

	/**
	 * Init Admin
	 * @author Daniel Barenkamp
	 * @version 1.0.0
	 * @since   1.0.0
	 * @link    https://welaunch.io
	 * @return  [type]             [description]
	 */
	public function init()
	{
		global $wordpress_form_wizard_options;
		$this->options = $wordpress_form_wizard_options;

		if (!$this->get_option('enable')) {
			return false;
		}

		add_action( 'admin_menu', array($this, 'wpse28782_remove_menu_items') );
        add_filter( 'manage_wizard_form_posts_columns', array($this, 'columns_head'));
        add_action( 'manage_wizard_form_posts_custom_column', array($this, 'columns_content'), 10, 1);
        add_filter( 'gettext', array($this, 'branded'), 20, 3);
	}

	public function wpse28782_remove_menu_items() 
	{
        remove_menu_page( 'edit.php?post_type=wizard_question' );
        remove_menu_page( 'edit.php?post_type=wizard_answer' );
	}

	public function branded($translation, $text, $domain) 
	{
		
		if(!$this->branded) {
			return $translation;
		}

		if($domain != "wordpress-form-wizard") {
			return $translation;
		}

		if($translation == "WordPress-Formularassistent") {
			$translation = 'WordPress Küchenpreisrechner';
		} elseif($translation == "weLaunch") {
			$translation = 'Asensu';
		} elseif($translation == "Wizard-Formulare") {
			$translation = 'Küchenpreisrechner';
		}

      	return $translation;
  	}
            /**
     * Columns Head.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    https://welaunch.io/plugins
     *
     * @param string $columns Columnd
     *
     * @return string
     */
    public function columns_head($columns)
    {
        $output = array();
        foreach ($columns as $column => $name) {
            $output[$column] = $name;

            if ($column === 'title') {
                $output['shortcode'] = esc_html__('Shortcode', 'wordpress-store-locator');
            }
        }

        return $output;
    }

    /**
     * Columns Content.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    https://welaunch.io/plugins
     *
     * @param string $column_name Column Name
     *
     * @return string
     */
    public function columns_content($column_name)
    {
        global $post;

        if ($column_name == 'shortcode') {
          
            echo '<pre>[wordpress_form_wizard id="' .  $post->ID . '"]</pre>';
        }
    }

    public function migrate_keys()
    {
        global $wpdb;

        $table = $wpdb->prefix . 'postmeta';
        $sql = "UPDATE $table SET meta_key = replace(meta_key, 'wordpress_kitchen_price_calculator_', 'wordpress_form_wizard_');";

        $wpdb->query($wpdb->prepare($sql));

        die('Keys migrated');
    }

}		