<?php
/**
 * Custom Post Type for Wizard Forms and Taxonomies.
 */
class WordPress_Form_Wizard_Analytics extends WordPress_Form_Wizard
{
    protected $plugin_name;
    protected $version;
    protected $prefix;
    /**
     * Constructor.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @param string $plugin_name
     * @param string $version
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        
        $this->prefix = "wordpress_form_wizard_";
    }

    /**
     * Init.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @return bool
     */
    public function init()
    {
        add_action('wp_ajax_wordpress_form_wizard_analytics_view', array($this, 'view') );
        add_action('wp_ajax_nopriv_wordpress_form_wizard_analytics_view', array($this, 'view') );

        add_action('wp_ajax_wordpress_form_wizard_analytics_complete', array($this, 'complete') );
        add_action('wp_ajax_nopriv_wordpress_form_wizard_analytics_complete', array($this, 'complete') );

    }

    /**
     * Save Points on Question Answered
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https:/welaunch.io
     * @return  [type]             [description]
     */
    public function view()
    {
        $response = array(
            'status' => 0,
            'message' => '',
            'data' => array()
        );

        if(current_user_can('administrator')) {
            $response['status'] = 1;
            $response['message'] = esc_html__('Not tracking admins.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!defined('DOING_AJAX') || !DOING_AJAX) {
            $response['message'] = esc_html__('No AJAX call', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!isset($_POST['form_id']) || empty($_POST['form_id'])) {
            $response['message'] = esc_html__('Form ID Missing.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!isset($_POST['step_id'])) {
            $response['message'] = esc_html__('Step ID Missing.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        $form_id = (int) $_POST['form_id'];
        $form = get_post($form_id);
        if(!$form) {
            $response['message'] = esc_html__('Form not found.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        $step_id = (int) $_POST['step_id'];
        if($step_id == 0) {
            $step_id = $form_id;
        }

        // Viewed this step or form (when step 0)
        $views = (int) get_post_meta($step_id, $this->prefix . 'views', true);
        if(!empty($views)) {
            $views += 1;
        } else {
            $views = 1;
        }

        update_post_meta($step_id, $this->prefix . 'views', $views);

        // Started the form (first step)
        if (isset($_POST['first_step']) && $_POST['first_step'] == "true") {
            $started = (int) get_post_meta($form_id, $this->prefix . 'started', true);
            if(!empty($started)) {
                $started += 1;
            } else {
                $started = 1;
            }
            update_post_meta($form_id, $this->prefix . 'started', $started);
        }

        // Finished the form (first step)
        if (isset($_POST['last_step']) && $_POST['last_step'] == "true") {
            $finished = (int) get_post_meta($form_id, $this->prefix . 'finished', true);
            if(!empty($finished)) {
                $finished += 1;
            } else {
                $finished = 1;
            }
            update_post_meta($form_id, $this->prefix . 'finished', $finished);
        }
            


        $response['status'] = 1;
        $response['message'] = esc_html__('Views updated.', 'wordpress-form-wizard');

        echo json_encode($response);
        die();
    }


    /**
     * Save Points on Question Answered
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https:/welaunch.io
     * @return  [type]             [description]
     */
    public function complete()
    {
        $response = array(
            'status' => 0,
            'message' => '',
            'data' => array()
        );

        if(current_user_can('administrator')) {
            $response['status'] = 1;
            $response['message'] = esc_html__('Not tracking admins.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!defined('DOING_AJAX') || !DOING_AJAX) {
            $response['message'] = esc_html__('No AJAX call', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!isset($_POST['form_id']) || empty($_POST['form_id'])) {
            $response['message'] = esc_html__('Form ID Missing.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!isset($_POST['step_id'])) {
            $response['message'] = esc_html__('Step ID Missing.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        $form_id = (int) $_POST['form_id'];
        $form = get_post($form_id);
        if(!$form) {
            $response['message'] = esc_html__('Form not found.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        $step_id = (int) $_POST['step_id'];

        // Viewed this step or form (when step 0)
        $completed = (int) get_post_meta($step_id, $this->prefix . 'completed', true);
        if(!empty($completed)) {
            $completed += 1;
        } else {
            $completed = 1;
        }

        update_post_meta($step_id, $this->prefix . 'completed', $completed);

        if(isset($_POST['choices']) && is_array($_POST['choices'])) {
            $choices = array_filter( $_POST['choices'] );
            var_dump($choices);
            if(isset($choices[$step_id])) {
                if(is_array($choices[$step_id])) {
                    foreach($choices[$step_id] as $singleChoice) {
                        $this->analytics_answer_view($singleChoice);
                    }
                } else {
                    $this->analytics_answer_view($choices[$step_id]);
                }
            }
        }

        $response['status'] = 1;
        $response['message'] = esc_html__('Completed updated.', 'wordpress-form-wizard');

        echo json_encode($response);
        die();
    }

    public function analytics_answer_view($answerId)
    {
        // Viewed this step or form (when step 0)
        $choosen = (int) get_post_meta($answerId, $this->prefix . 'choosen', true);
        if(!empty($choosen)) {
            $choosen += 1;
        } else {
            $choosen = 1;
        }

        update_post_meta($answerId, $this->prefix . 'choosen', $choosen);
    }
}