<?php
/**
 * Custom Post Type for Wizard Forms and Taxonomies.
 */
class WordPress_Form_Wizard_Forms extends WordPress_Form_Wizard
{
    protected $plugin_name;
    protected $version;
    protected $prefix;
    /**
     * Constructor.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @param string $plugin_name
     * @param string $version
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
        
        $this->prefix = "wordpress_form_wizard_";
    }

    /**
     * Init.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @return bool
     */
    public function init()
    {
        $this->register_form_wizard_post_type();
   }

    /**
     * Register Wizard Form Post Type.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @return bool
     */
    public function register_form_wizard_post_type()
    {
        $singular = esc_html__('Wizard Form', 'wordpress-form-wizard');
        $plural = esc_html__('Wizard Forms', 'wordpress-form-wizard');

        $labels = array(
            'name' => esc_html__('Wizard Forms', 'wordpress-form-wizard'),
            'all_items' => $plural,
            'singular_name' => $singular,
            'add_new' => sprintf(__('New %s', 'wordpress-form-wizard'), $singular),
            'add_new_item' => sprintf(__('Add New %s', 'wordpress-form-wizard'), $singular),
            'edit_item' => sprintf(__('Edit %s', 'wordpress-form-wizard'), $singular),
            'new_item' => sprintf(__('New %s', 'wordpress-form-wizard'), $singular),
            'view_item' => sprintf(__('View %s', 'wordpress-form-wizard'), $plural),
            'search_items' => sprintf(__('Search %s', 'wordpress-form-wizard'), $plural),
            'not_found' => sprintf(__('No %s found', 'wordpress-form-wizard'), $plural),
            'not_found_in_trash' => sprintf(__('No %s found in trash', 'wordpress-form-wizard'), $plural),
        );

        $args = array(
            'labels' => $labels,
            'public' => false,
            'exclude_from_search' => false,
            'show_ui' => true,
            'menu_position' => 57,
            'query_var' => 'wizard-form',
            'supports' => array('title', 'author'),
            'menu_icon' => 'dashicons-welcome-learn-more',
        );

        register_post_type('wizard_form', $args);

    }


    /**
     * Columns Head.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @param string $columns Columnd
     *
     * @return string
     */
    public function columns_head($columns)
    {
        $output = array();
        foreach ($columns as $column => $name) {
            $output[$column] = $name;

            if ($column === 'title') {
                $output['visibility'] = esc_html__('Visibility', 'wordpress-form_wizard');
            }
        }

        return $output;
    }

    /**
     * Columns Content.
     *
     * @author Daniel Barenkamp
     *
     * @version 1.0.0
     *
     * @since   1.0.0
     * @link    http://www.welaunch.io
     *
     * @param string $column_name Column Name
     *
     * @return string
     */
    public function columns_content($column_name)
    {
        global $post;

        if ($column_name == 'visibility') {
            $visibility = get_post_meta($post->ID, 'visibility', true);
            echo $visibility;
        }
    }

    /**
     * Add custom ticket metaboxes
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https://www.welaunch.io
     * @param   [type]                       $post_type [description]
     * @param   [type]                       $post      [description]
     */
    public function add_custom_metaboxes($post_type, $post)
    {
        add_meta_box('wordpress-form-wizard-general', esc_html__('General', 'wordpress-form-wizard'), array($this, 'general'), 'wizard_form', 'normal', 'high');
        add_meta_box('wordpress-form-wizard-questions', esc_html__('Questions', 'wordpress-form-wizard'), array($this, 'questions'), 'wizard_form', 'normal', 'high');
        add_meta_box('wordpress-form-wizard-final', esc_html__('Final', 'wordpress-form-wizard'), array($this, 'final'), 'wizard_form', 'normal', 'high');

        global $wordpress_form_wizard_options;
    }

    /**
     * Display Metabox Address
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https://www.welaunch.io
     * @return  [type]                       [description]
     */
    public function general()
    {
        global $post;

        wp_nonce_field(basename(__FILE__), 'wordpress_form_wizard_meta_nonce');

        if($this->is_new()) {

            $type = "price_calculation"; 

            $show_progress_bar = "yes";
            $show_mail = "yes";
            $show_live_price = "yes";
            $show_answer_prices = "no";
            $show_back_button = "yes";
            $show_price_in_final_step = "yes";

            $intro = "";
            $price_calculation = "";
            $show_results_at = "";
            
            $title = "";
            
            $show_email = "yes";
            $views = 0;
            $started = 0;
            $finished = 0;

        } else {

            $type = get_post_meta($post->ID, $this->prefix . 'type', true);

            $show_progress_bar = get_post_meta($post->ID, $this->prefix . 'show_progress_bar', true);
            $show_live_price = get_post_meta($post->ID, $this->prefix . 'show_live_price', true);
            $show_answer_prices = get_post_meta($post->ID, $this->prefix . 'show_answer_prices', true);
            $show_mail = get_post_meta($post->ID, $this->prefix . 'show_mail', true);
            $show_back_button = get_post_meta($post->ID, $this->prefix . 'show_back_button', true);
            $show_price_in_final_step = get_post_meta($post->ID, $this->prefix . 'show_price_in_final_step', true);

            $intro = get_post_meta($post->ID, $this->prefix . 'intro', true);
            
            $show_email = get_post_meta($post->ID, $this->prefix . 'show_email', true);

            $show_progress_bar = get_post_meta($post->ID, $this->prefix . 'show_progress_bar', true);
            $intro = get_post_meta($post->ID, $this->prefix . 'intro', true);
            $price_calculation = get_post_meta($post->ID, $this->prefix . 'price_calculation', true);
            $show_results_at = get_post_meta($post->ID, $this->prefix . 'show_results_at', true);
            $title = get_post_meta($post->ID, $this->prefix . 'title', true);

            $views = (int) get_post_meta($post->ID, $this->prefix . 'views', true);
            $started = (int) get_post_meta($post->ID, $this->prefix . 'started', true);
            $finished = (int) get_post_meta($post->ID, $this->prefix . 'finished', true);

        }

        $types = array(
            'price_calculation' => esc_html__( 'Price Calculation', 'wordpress-form-wizard' ),
            'guided_selling' => esc_html__( 'Guided Selling', 'wordpress-form-wizard' ),
        );

        $yes_no = array(
            'no' => esc_html__('No', 'wordpress-form-wizard'),
            'yes' => esc_html__('Yes', 'wordpress-form-wizard'),
        );

        $postTypes = array();
        if($type == "guided_selling") {
            global $wpdb;
            $post_types = array();
            $res = $wpdb->get_results("SELECT DISTINCT post_type FROM `{$wpdb->prefix}posts`", ARRAY_A);
            if(!empty($res)) {
                foreach ($res as $key => $value) {
                    $post_types[] = $value['post_type'];
                }
            }
            $post_types = array_combine($post_types, $post_types);

            $postTypesSelected = get_post_meta($post->ID, $this->prefix . 'post_types', true);
        }

        if(empty($postTypesSelected)) {
            $postTypesSelected = array();
        }

        ?>
        <div class="wordpress-form-wizard-form-general">
            <div class="wordpress-form-wizard-row">
                <div class="wordpress-form-wizard-col-xs-3">
                    <div class="wordpress-form-wizard-badge wordpress-form-wizard-badge-info">
                        <div class="wordpress-form-wizard-badge-title">
                            <?php echo $views ?>
                        </div>
                        <div class="wordpress-form-wizard-badge-text">
                            <?php esc_html_e('Viewed', 'wordpress-form-wizard'); ?>
                        </div>
                    </div>
                </div>
                <div class="wordpress-form-wizard-col-xs-3">
                    <div class="wordpress-form-wizard-badge wordpress-form-wizard-badge-primary">
                        <div class="wordpress-form-wizard-badge-title">
                            <?php echo $started ?>
                        </div>
                        <div class="wordpress-form-wizard-badge-text">
                            <?php esc_html_e('Started', 'wordpress-form-wizard'); ?>
                        </div>
                    </div>
                </div>
                <div class="wordpress-form-wizard-col-xs-3">
                    <div class="wordpress-form-wizard-badge wordpress-form-wizard-badge-alert">
                        <div class="wordpress-form-wizard-badge-title">
                            <?php echo $finished ?>
                        </div>
                        <div class="wordpress-form-wizard-badge-text">
                            <?php esc_html_e('Finished', 'wordpress-form-wizard'); ?>
                        </div>
                    </div>
                </div>
                <div class="wordpress-form-wizard-col-xs-3">
                    <div class="wordpress-form-wizard-badge wordpress-form-wizard-badge-success">
                        <div class="wordpress-form-wizard-badge-title">
                            <?php echo $started - $finished ?>
                        </div>
                        <div class="wordpress-form-wizard-badge-text">
                            <?php esc_html_e('Bounced', 'wordpress-form-wizard'); ?>
                        </div>
                    </div>
                </div>
            </div>


            <div class="wordpress-form-wizard-row">

                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>type">
                        <?php esc_html_e( 'Type', 'wordpress-form-wizard' ) ?>
                        <span class="wordpress-form-wizard-tooltip" wordpress-form-wizard-tooltip="<?php esc_html_e( 'When you change the type, please save the form to reload this page.', 'wordpress-form-wizard' ) ?>">
                            <i class="bx bxs-info-circle"></i>
                        </span>        
                    </label>
                    <select name="<?php echo $this->prefix ?>type" class="wordpress-form-wizard-input-field">
                    <?php 
                    foreach ($types as $key => $type_name) {
                        $selected = "";
                        if($type == $key) {
                            $selected = 'selected="selected"';
                        }
                        echo '<option value="' . $key . '" ' . $selected . '>' . $type_name . '</option>';
                    }
                    ?>
                    </select>
                </div>

                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>show_progress_bar"><?php esc_html_e( 'Show Progress Bar', 'wordpress-form-wizard' ) ?></label>
                    <select name="<?php echo $this->prefix ?>show_progress_bar" class="wordpress-form-wizard-input-field">
                    <?php 
                    foreach ($yes_no as $key => $show_progress_bar_name) {
                        $selected = "";
                        if($show_progress_bar == $key) {
                            $selected = 'selected="selected"';
                        }
                        echo '<option value="' . $key . '" ' . $selected . '>' . $show_progress_bar_name . '</option>';
                    }
                    ?>
                    </select>
                </div>

                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>show_email"><?php esc_html_e( 'Show Mail Form', 'wordpress-form-wizard' ) ?></label>
                    <select name="<?php echo $this->prefix ?>show_email" class="wordpress-form-wizard-input-field">
                    <?php 
                    foreach ($yes_no as $key => $show_email_name) {
                        $selected = "";
                        if($show_email == $key) {
                            $selected = 'selected="selected"';
                        }
                        echo '<option value="' . $key . '" ' . $selected . '>' . $show_email_name . '</option>';
                    }
                    ?>
                    </select>
                </div>

                <?php if($type == "price_calculation") { ?>
                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>show_live_price"><?php esc_html_e( 'Show Live Price', 'wordpress-form-wizard' ) ?></label>
                    <select name="<?php echo $this->prefix ?>show_live_price" class="wordpress-form-wizard-input-field">
                    <?php 
                    foreach ($yes_no as $key => $show_live_price_name) {
                        $selected = "";
                        if($show_live_price == $key) {
                            $selected = 'selected="selected"';
                        }
                        echo '<option value="' . $key . '" ' . $selected . '>' . $show_live_price_name . '</option>';
                    }
                    ?>
                    </select>
                </div>

                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>price_calculation">
                        <?php esc_html_e( 'Price Calculation Formula', 'wordpress-form-wizard' ) ?>
                        <span class="wordpress-form-wizard-tooltip" wordpress-form-wizard-tooltip="<?php esc_html_e( 'Use #ID (question id) for calculation. Example: 500+(#41*#43)', 'wordpress-form-wizard' ) ?>">
                            <i class="bx bxs-info-circle"></i>
                        </span>
                    </label>
                    <input type="text" name="<?php echo $this->prefix ?>price_calculation" class="wordpress-form-wizard-input-field" value="<?php echo $price_calculation ?>">
                </div>

                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>show_answer_prices"><?php esc_html_e( 'Show Answer Prices', 'wordpress-form-wizard' ) ?></label>
                    <select name="<?php echo $this->prefix ?>show_answer_prices" class="wordpress-form-wizard-input-field">
                    <?php 
                    foreach ($yes_no as $key => $show_answer_prices_name) {
                        $selected = "";
                        if($show_answer_prices == $key) {
                            $selected = 'selected="selected"';
                        }
                        echo '<option value="' . $key . '" ' . $selected . '>' . $show_answer_prices_name . '</option>';
                    }
                    ?>
                    </select>
                </div>
                
                <?php } else {  ?>
                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>post_types[]">
                        <?php esc_html_e( 'Post Types', 'wordpress-form-wizard' ) ?>
                        <span class="wordpress-form-wizard-tooltip" wordpress-form-wizard-tooltip="<?php esc_html_e( 'Select the post types, that should show in end results.', 'wordpress-form-wizard' ) ?>">
                            <i class="bx bxs-info-circle"></i>
                    </label>
                    <select name="<?php echo $this->prefix ?>post_types[]" class="wordpress-form-wizard-input-field welaunch-select2" multiple>
                    <?php 
                    foreach ($post_types as $key => $post_types_name) {
                        $selected = "";
                        if(in_array($key, $postTypesSelected)) {
                            $selected = 'selected="selected"';
                        }
                        echo '<option value="' . $key . '" ' . $selected . '>' . $post_types_name . '</option>';
                    }
                    ?>
                    </select>
                </div>
                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>show_results_at">
                        <?php esc_html_e( 'Show Results at', 'wordpress-form-wizard' ) ?>
                        <span class="wordpress-form-wizard-tooltip" wordpress-form-wizard-tooltip="<?php esc_html_e( 'Leave empty to show results always at the end.', 'wordpress-form-wizard' ) ?>">
                            <i class="bx bxs-info-circle"></i>
                    </label>
                    <input type="number" step="1" name="<?php echo $this->prefix ?>show_results_at" class="wordpress-form-wizard-input-field" value="<?php echo $show_results_at ?>">
                </div>
                <?php } ?>

                <div class="wordpress-form-wizard-col-xs-6">
                    <label for="<?php echo $this->prefix ?>title"><?php esc_html_e( 'Title', 'wordpress-form-wizard' ) ?></label>
                    <input type="text" name="<?php echo $this->prefix ?>title" class="wordpress-form-wizard-input-field" value="<?php echo $title ?>">
                </div>

                <div class="wordpress-form-wizard-col-xs-12">
                    <label for="<?php echo $this->prefix ?>intro">
                        <?php echo esc_html__( 'Intro', 'wordpress-form-wizard' ) ?>
                        <span class="wordpress-form-wizard-tooltip" wordpress-form-wizard-tooltip="<?php esc_html_e( 'Hint: You can use shortcodes here and leave the title above empty.', 'wordpress-form-wizard' ) ?>">
                            <i class="bx bxs-info-circle"></i>
                    </label>
                    <?php 
                    echo wp_editor( $intro, $this->prefix . 'intro', array(
                        'textarea_rows' => 5
                    ) );
                    ?>
                </div>

            </div>

        </div>

        <?php

    }

    /**
     * Display Metabox Address
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https://www.welaunch.io
     * @return  [type]                       [description]
     */
    public function questions()
    {
        global $post;
        $questions = get_post_meta($post->ID, $this->prefix . 'questions', true);
        if(!empty($questions)) {
            $questions = get_posts(array(
                'post_type' => 'wizard_question',
                'post__in' => $questions,
                'post_status' => 'any, trash',
                'orderby' => 'post__in',
                'numberposts' => '-1',
            ));
        } else {
            $questions = array();
        }
        ?>

        <div class="wordpress-form-wizard-questions-header">
            <div class="wordpress-form-wizard-row">
                <div class="wordpress-form-wizard-col-xs-1" style="max-width: 50px";>
                    
                </div>
                <div class="wordpress-form-wizard-col-xs-5">
                    <?php esc_html_e('Name', 'wordpress-form-wizard') ?>
                </div>
                <div class="wordpress-form-wizard-col-xs-1">
                    <?php esc_html_e('Type', 'wordpress-form-wizard') ?>
                </div>
                <div class="wordpress-form-wizard-col-xs-1">
                    <?php esc_html_e('Viewed', 'wordpress-form-wizard') ?>
                </div>
                <div class="wordpress-form-wizard-col-xs-1">
                    <?php esc_html_e('Completed', 'wordpress-form-wizard') ?>
                </div>
                <div class="wordpress-form-wizard-col-xs-1">
                    <?php esc_html_e('Bounced', 'wordpress-form-wizard') ?>
                </div>
                <div class="wordpress-form-wizard-col-xs-2">
                    <?php esc_html_e('Actions', 'wordpress-form-wizard') ?>
                </div>
            </div>  
        </div>
        <div class="wordpress-form-wizard-questions">

            <div class="wordpress-form-wizard-questions-question wordpress-form-wizard-questions-question-template" style="display: none;">

                <input type="hidden" class="wordpress-form-wizard-questions-question-id" name="questionId" value="">

                <div class="wordpress-form-wizard-row">
                    <div class="wordpress-form-wizard-col-xs-1 wordpress-form-wizard-sort-container">
                        <i class='bx bx-dots-vertical-rounded'></i>    
                    </div>
                    <div class="wordpress-form-wizard-col-xs-5">
                        <div class="wordpress-form-wizard-questions-question-name">
                            
                        </div>
                    </div>
                    <div class="wordpress-form-wizard-col-xs-1">
                        <i class='bx bx-check-circle' ></i>
                    </div>

                    <div class="wordpress-form-wizard-col-xs-1">
                        <div class="wordpress-form-wizard-questions-question-interacted">
                            <span class="wordpress-form-wizard-badge wordpress-form-wizard-badge-primary">0</span>
                        </div>
                    </div>

                    <div class="wordpress-form-wizard-col-xs-1">
                        <div class="wordpress-form-wizard-questions-question-bounced">
                            <span class="wordpress-form-wizard-badge wordpress-form-wizard-badge-success">0</span>
                        </div>
                    </div>

                    <div class="wordpress-form-wizard-col-xs-1">
                        <div class="wordpress-form-wizard-questions-question-bounced">
                            <span class="wordpress-form-wizard-badge wordpress-form-wizard-badge-alert">0</span>
                        </div>
                    </div>

                    <div class="wordpress-form-wizard-col-xs-2">
                        <div class="wordpress-form-wizard-questions-question-actions">
                            <a class="wordpress-form-wizard-questions-question-actions-edit" href="#"><i class='bx bx-pencil'></i></a>
                            <a class="wordpress-form-wizard-questions-question-actions-hide" href="#"><i class='bx bx-hide'></i></a>
                        </div>
                    </div>
                </div>  
            </div>

            <?php 
            foreach($questions as $question) { 

                $views = (int) get_post_meta($question->ID, $this->prefix . 'views', true);
                $completed = (int) get_post_meta($question->ID, $this->prefix . 'completed', true);
                $internal = get_post_meta($question->ID, $this->prefix . 'internal', true);
                $type = get_post_meta($question->ID, $this->prefix . 'type', true);
                $name = $question->post_title;
                if(!empty($internal)) {
                    $name = $internal;
                }

            ?>
            <div class="wordpress-form-wizard-questions-question <?php echo $question->post_status == "trash" ? 'wordpress-form-wizard-questions-question-disabled' : '' ?>">

                <input type="hidden" class="wordpress-form-wizard-questions-question-id" name="questionId" value="<?php echo $question->ID ?>">

                <div class="wordpress-form-wizard-row">
                    <div class="wordpress-form-wizard-col-xs-1 wordpress-form-wizard-sort-container">
                        <i class='bx bx-dots-vertical-rounded'></i>    
                    </div>
                    <div class="wordpress-form-wizard-col-xs-5">
                        <div class="wordpress-form-wizard-questions-question-name">
                            <?php echo $name ?> <small><?php echo esc_html__('ID: ', 'wordpress-form-wizard') . $question->ID ?></small>
                        </div>
                    </div>
                    <div class="wordpress-form-wizard-col-xs-1">
                        <?php 
                        if ($type == "checkbox") {
                            echo '<i class="bx bx-check-square"></i>';
                        } elseif($type == "slider") {
                            echo '<i class="bx bx-slider"></i>';
                        } else {
                            echo '<i class="bx bx-check-circle"></i>';
                        }
                        ?> 
                    </div>
                    <div class="wordpress-form-wizard-col-xs-1">
                        <div class="wordpress-form-wizard-questions-question-interacted">
                            <span class="wordpress-form-wizard-badge wordpress-form-wizard-badge-primary"><?php echo $views ?></span>
                        </div>
                    </div>

                    <div class="wordpress-form-wizard-col-xs-1">
                        <div class="wordpress-form-wizard-questions-question-bounced">
                            <span class="wordpress-form-wizard-badge wordpress-form-wizard-badge-success"><?php echo $completed ?></span>
                        </div>
                    </div>

                    <div class="wordpress-form-wizard-col-xs-1">
                        <div class="wordpress-form-wizard-questions-question-bounced">
                            <span class="wordpress-form-wizard-badge wordpress-form-wizard-badge-alert"><?php echo $views - $completed ?></span>
                        </div>
                    </div>
                    <div class="wordpress-form-wizard-col-xs-2">
                        <div class="wordpress-form-wizard-questions-question-actions">
                            <a class="wordpress-form-wizard-questions-question-actions-edit" href="<?php echo admin_url('post.php?post=' . $question->ID . '&action=edit') ?>"><i class='bx bx-pencil'></i></a>
                            
                            <?php if($question->post_status == "trash") { ?>
                            <a class="wordpress-form-wizard-questions-question-actions-show" data-id="<?php echo $question->ID ?>" href=""><i class='bx bx-show'></i></a>
                            <?php } else { ?>
                            <a class="wordpress-form-wizard-questions-question-actions-hide" data-id="<?php echo $question->ID ?>" href=""><i class='bx bx-hide'></i></a>
                            <?php } ?>
                        </div>
                    </div>
                </div>  
            </div>
            <?php } ?>

        </div>
        <div class="wordpress-form-wizard-actions">
            <div class="wordpress-form-wizard-row">
                <div class="wordpress-form-wizard-col-xs-12">
                    <a href="#" class="wordpress-form-wizard-actions-action wordpress-form-wizard-actions-add-question"><?php esc_html_e('Add Question', 'wordpress-form-wizard') ?></a>
                </div>
            </div>
        </div> 
        <?php
    }

    public function final() 
    {
        global $post;

        if($this->is_new()) {
            $final_text = esc_html__('Finish! Please see your result below.', 'wordpress-form-wizard');
            $show_final_price = "yes";
        } else {
            $final_text = get_post_meta($post->ID, $this->prefix . 'final_text', true);
            $show_final_price = get_post_meta($post->ID, $this->prefix . 'show_final_price', true);
        }

        $yes_no = array(
            'no' => esc_html__('No', 'wordpress-form-wizard'),
            'yes' => esc_html__('Yes', 'wordpress-form-wizard'),
        );

        ?>

        <div class="wordpress-form-wizard-row">

            <div class="wordpress-form-wizard-col-xs-12">
                <label for="<?php echo $this->prefix ?>show_final_price">
                    <?php esc_html_e( 'Show Final Price', 'wordpress-form-wizard' ) ?>
                    <span class="wordpress-form-wizard-tooltip" wordpress-form-wizard-tooltip="<?php esc_html_e( 'Hint: you can disable to show the price in final step, so that users only their price in the mail.', 'wordpress-form-wizard' ) ?>">
                            <i class="bx bxs-info-circle"></i>
                </label>
                <select name="<?php echo $this->prefix ?>show_final_price" class="wordpress-form-wizard-input-field">
                <?php 
                foreach ($yes_no as $key => $show_final_price_name) {
                    $selected = "";
                    if($show_final_price == $key) {
                        $selected = 'selected="selected"';
                    }
                    echo '<option value="' . $key . '" ' . $selected . '>' . $show_final_price_name . '</option>';
                }
                ?>
                </select>
            </div>

            <div class="wordpress-form-wizard-col-xs-12">
                <label for="<?php echo $this->prefix ?>final_text"><?php echo esc_html__( 'Final Text', 'wordpress-form-wizard' ) ?></label>
                <?php 
                echo wp_editor( $final_text, $this->prefix . 'final_text', array(
                    'textarea_rows' => 5
                ) );
                ?>
            </div>

        </div>
        <?php
    }

    private function is_new()
    {
        global $pagenow;

        if (!is_admin()) return false;

        return in_array( $pagenow, array( 'post-new.php' ) );
    }

    /**
     * Save Custom Metaboxes
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https://www.welaunch.io
     * @param   [type]                       $post_id [description]
     * @param   [type]                       $post    [description]
     * @return  [type]                                [description]
     */
    public function save_custom_metaboxes($post_id, $post)
    {
        global $wordpress_form_wizard_options;

        if($post->post_type !== "wizard_form") {
            return false;
        }

        // Is the user allowed to edit the post or page?
        if (!current_user_can('edit_post', $post->ID)) {
            return $post->ID;
        }

        if ($post->post_type == 'revision') {
            return false;
        }

        if (!isset($_POST['wordpress_form_wizard_meta_nonce']) || !wp_verify_nonce($_POST['wordpress_form_wizard_meta_nonce'], basename(__FILE__))) {
            return false;
        }
        
        // Add values of $ticket_meta as custom fields
        foreach ($_POST as $postKey => $postData) {

            if(!str_contains( $postKey, 'wordpress_form_wizard_')) {
                continue;
            }

            update_post_meta($post->ID, $postKey, $postData);
        }
    }


}
